@@ -1,5 +1,5 @@
 `lines.crosspred` <-
-function(x, ptype="overall", var=NULL, lag=NULL, ci="n", 
+function(x, ptype="overall", var=NULL, lag=NULL, ci="n", ci.arg,
 	ci.level=x$ci.level, cumul=FALSE, exp=NULL, ...) {
 
 ###########################################################################
@@ -27,6 +27,9 @@ if(!is.null(lag)&&!lag%in%0:x$maxlag&&(ptype=="slices")) {
 if(!ci%in%c("area","bars","lines","n")) {
 	stop("'ci' must be one of 'area', 'bars', 'lines' or 'n'")
 }
+if(missing(ci.arg)) {
+	ci.arg <- list()
+} else if(!is.list(ci.arg)) stop("'ci.arg' must be a list")
 if(!is.numeric(ci.level)||ci.level>=1||ci.level<=0) {
 	stop("'ci.level' must be numeric and between 0 and 1")
 }
@@ -67,17 +70,28 @@ if((is.null(exp)&&x$model.link%in%c("log","logit"))||
 # GRAPHS
 
 # FUNCTION TO CREATE CONFIDENCE INTERVALS
-fci.lines <- function(ci,x,high,low,colarea=grey(0.9),collines=2) {
+fci.lines <- function(ci,x,high,low,ci.arg,plot.arg) {
 	if(ci=="area") {
-		polygon(c(x,rev(x)),c(high,rev(low)),col=colarea,border="white")
+		polygon.arg <- modifyList(list(col=grey(0.9),border=NA),ci.arg)
+		polygon.arg <- modifyList(polygon.arg,
+			list(x=c(x,rev(x)),y=c(high,rev(low))))
+		do.call(polygon,polygon.arg)
 	} else if(ci=="bars") {
 		range <- diff(range(x))/300
-		segments(x,high,x,low)
-		segments(x-range,high,x+range,high)
-		segments(x-range,low,x+range,low)
+		segments.arg <- modifyList(ci.arg,list(x0=x,y0=high,x1=x,y1=low))
+		do.call(segments,segments.arg)
+		segments.arg <- modifyList(segments.arg,list(x0=x-range,y0=high,
+			x1=x+range,y1=high))
+		do.call(segments,segments.arg)
+		segments.arg <- modifyList(segments.arg,list(x0=x-range,y0=low,
+			x1=x+range,y1=low))
+		do.call(segments,segments.arg)
 	} else if(ci=="lines") {
-		lines(x,high,lty=2,col=collines)
-		lines(x,low,lty=2,col=collines)
+		lines.arg <- modifyList(list(lty=2,col=plot.arg$col),ci.arg)
+		lines.arg <- modifyList(lines.arg,list(x=x,y=high))
+		do.call(lines,lines.arg)
+		lines.arg <- modifyList(lines.arg,list(x=x,y=low))
+		do.call(lines,lines.arg)
 	}
 }
 
@@ -93,15 +107,15 @@ if(ptype=="slices") {
 		xlag <- paste("lag",lag,sep="")
 
 		# SET DEFAULT VALUES IF NOT INCLUDED BY THE USER
-		argdef <- list(type="l",col=2)
-		argdef <- modifyList(argdef,list(...))		
+		plot.arg <- list(type="l",col=2)
+		plot.arg <- modifyList(plot.arg,list(...))		
 
 		# PLOT CONFIDENCE INTERVALS (IF ANY)
 		fci.lines(ci=ci,x=x$predvar,high=x$mathigh[,xlag],
-			low=x$matlow[,xlag],colarea=grey(0.9),collines=argdef$col)
-		argdef <- modifyList(argdef,c(list(x=x$predvar,
+			low=x$matlow[,xlag],ci.arg,plot.arg)
+		plot.arg <- modifyList(plot.arg,c(list(x=x$predvar,
 			y=x$matfit[,xlag])))
-		do.call(lines,argdef)
+		do.call(lines,plot.arg)
 	}
 
 	# VAR
@@ -110,15 +124,15 @@ if(ptype=="slices") {
 		xvar <- as.character(var)
 
 		# SET DEFAULT VALUES IF NOT INCLUDED BY THE USER
-		argdef <- list(type="l",col=2)
-		argdef <- modifyList(argdef,list(...))		
+		plot.arg <- list(type="l",col=2)
+		plot.arg <- modifyList(plot.arg,list(...))		
 
 		# PLOT CONFIDENCE INTERVALS (IF ANY)
 		fci.lines(ci=ci,x=0:x$maxlag,high=x$mathigh[xvar,],
-			low=x$matlow[xvar,],colarea=grey(0.9),collines=argdef$col)
-		argdef <- modifyList(argdef,c(list(x=0:x$maxlag,
+			low=x$matlow[xvar,],ci.arg,plot.arg)
+		plot.arg <- modifyList(plot.arg,c(list(x=0:x$maxlag,
 			y=x$matfit[xvar,])))
-		do.call(lines,argdef)
+		do.call(lines,plot.arg)
 	}
 
 }
@@ -130,16 +144,16 @@ if(ptype=="slices") {
 if(ptype=="overall") {
 
 	# SET DEFAULT VALUES IF NOT INCLUDED BY THE USER
-	argdef <- list(type="l",col=2)
-	argdef <- modifyList(argdef,list(...))
+	plot.arg <- list(type="l",col=2)
+	plot.arg <- modifyList(plot.arg,list(...))
 	
 	# SET CONFIDENCE INTERVALS
 	fci.lines(ci=ci,x=x$predvar,high=x$allhigh,
-		low=x$alllow,colarea=grey(0.9),collines=argdef$col)
-	argdef <- modifyList(argdef,c(list(x=x$predvar,y=x$allfit)))
+		low=x$alllow,ci.arg,plot.arg)
+	plot.arg <- modifyList(plot.arg,c(list(x=x$predvar,y=x$allfit)))
 
 	# PLOT
-	do.call(lines,argdef)
+	do.call(lines,plot.arg)
 }
 }
 
